Glossary
========

+-------------------+------------------------------+---------------------------------------+
| Term              | Definition                   | Reference                             |
+===================+==============================+=======================================+
| .. _cllabel:      | A continuous 12-month period | `Hammond et al. (2022)`_              |
|                   | selected to present data     |                                       |
| Climate Year      | relative to climatic         |                                       |
|                   | phenomena during which the   |                                       |
|                   | annual low-flow period       |                                       |
|                   | normally occurs. The climate |                                       |
|                   | year used by the U.S.        |                                       |
|                   | Geological Survey runs from  |                                       |
|                   | April 1 to March 31, and is  |                                       |
|                   | designated by the year in    |                                       |
|                   | which it ends.               |                                       |
+-------------------+------------------------------+---------------------------------------+
| .. _wylabel:      | A continuous 12-month period | `USGS Water Science Glossary`_        |
|                   | selected to present data     |                                       |
| Water Year        | relative to hydrologic or    |                                       |
|                   | meteorological phenomena     |                                       |
|                   | during which a complete      |                                       |
|                   | annual hydrologic cycle      |                                       |
|                   | normally occurs. The water   |                                       |
|                   | year used by the U.S.        |                                       |
|                   | Geological Survey runs from  |                                       |
|                   | October 1 through September  |                                       |
|                   | 30, and is designated by the |                                       |
|                   | year in which it ends.       |                                       |
+-------------------+------------------------------+---------------------------------------+
| Hydrograph        | A plot of streamflow         | `USDA National Engineering Handbook`_ |
|                   | (discharge) versus time.     |                                       |
+-------------------+------------------------------+---------------------------------------+
| Streamflow        | The water discharge that     | `USGS Water Science Glossary`_        |
|                   | occurs in a natural channel. |                                       |
|                   | Typically, synonymous with   |                                       |
|                   | discharge or flow.           |                                       |
+-------------------+------------------------------+---------------------------------------+
| Discharge         | The volume of water that     | `USGS Water Science Glossary`_        |
|                   | passes a given location      |                                       |
|                   | within a given period of     |                                       |
|                   | time. Usually expressed in   |                                       |
|                   | cubic feet per second.       |                                       |
|                   | Typically, synonymous with   |                                       |
|                   | streamflow or flow.          |                                       |
+-------------------+------------------------------+---------------------------------------+
| Percentile        | The value below which a      | `USGS Water Science Glossary`_        |
|                   | given percentage of          |                                       |
|                   | observations in a group of   |                                       |
|                   | observations fall. For       |                                       |
|                   | example, the 20th percentile |                                       |
|                   | is the value below which 20  |                                       |
|                   | percent of the observations  |                                       |
|                   | may be found.                |                                       |
+-------------------+------------------------------+---------------------------------------+
| NWIS              | National Water Information   | `USGS NWIS`_                          |
|                   | System                       |                                       |
+-------------------+------------------------------+---------------------------------------+
| Flow duration     | A cumulative frequency curve | `Searcy (1959)`_                      |
| curve             | showing the percent of time  |                                       |
|                   | specified discharges were    |                                       |
|                   | equaled or exceeded during a |                                       |
|                   | given period of record.      |                                       |
+-------------------+------------------------------+---------------------------------------+
| hyswap            | HYdrologic Surface Water     | `hyswap`_                             |
|                   | Analysis Package             |                                       |
+-------------------+------------------------------+---------------------------------------+
| Raster            | Pixed-based visualization    | `Koehler (2004)`_                     |
| hydrograph        | of, typically, streamflow    |                                       |
|                   | data with years on the y-axis|                                       |
|                   | and days on the x-axis.      |                                       |
+-------------------+------------------------------+---------------------------------------+
| Metadata          | Data that provides           |                                       |
|                   | information about other data.|                                       |
+-------------------+------------------------------+---------------------------------------+
| Cubic feet per    | A rate of the flow, in       | `USGS Water Science Glossary`_        |
| second (cfs)      | streams and rivers, for      |                                       |
|                   | example. It is equal to a    |                                       |
|                   | volume of water one foot     |                                       |
|                   | high and one foot wide       |                                       |
|                   | flowing a distance of one    |                                       |
|                   | foot in one second. One      |                                       |
|                   | "cfs" is equal to 7.48       |                                       |
|                   | gallons of water flowing     |                                       |
|                   | each second.                 |                                       |
+-------------------+------------------------------+---------------------------------------+
| Drainage Basin    | Land area where              | `USGS Water Science Glossary`_        |
|                   | precipitation runs off into  |                                       |
|                   | streams, rivers, lakes, and  |                                       |
|                   | reservoirs. It is a land     |                                       |
|                   | feature that can be          |                                       |
|                   | identified by tracing a line |                                       |
|                   | along the highest elevations |                                       |
|                   | between two areas on a map,  |                                       |
|                   | often a ridge. Large         |                                       |
|                   | drainage basins, like the    |                                       |
|                   | area that drains into the    |                                       |
|                   | Mississippi River contain    |                                       |
|                   | thousands of smaller drainage|                                       |
|                   | basins. Also called a        |                                       |
|                   | "watershed."                 |                                       |
+-------------------+------------------------------+---------------------------------------+
| Rating Curve      | A drawn curve showing the    | `USGS Water Science Glossary`_        |
|                   | relation between gage height |                                       |
|                   | and discharge of a stream at |                                       |
|                   | a given gaging station.      |                                       |
+-------------------+------------------------------+---------------------------------------+
| Runoff            | (1) That part of the         | `USGS Water Science Glossary`_        |
|                   | precipitation, snow melt, or |                                       |
|                   | irrigation water that        |                                       |
|                   | appears in uncontrolled      |                                       |
|                   | surface streams, rivers,     |                                       |
|                   | drains or sewers. Runoff may |                                       |
|                   | be classified according to   |                                       |
|                   | speed of appearance after    |                                       |
|                   | rainfall or melting snow as  |                                       |
|                   | direct runoff or base        |                                       |
|                   | runoff, and according to     |                                       |
|                   | source as surface runoff,    |                                       |
|                   | storm interflow, or          |                                       |
|                   | groundwater runoff. (2) The  |                                       |
|                   | total discharge described in |                                       |
|                   | (1), above, during a         |                                       |
|                   | specified period of time.    |                                       |
|                   | (3) Also defined as the depth|                                       |
|                   | to which a drainage area     |                                       |
|                   | would be covered if all of   |                                       |
|                   | the runoff for a given period|                                       |
|                   | of time were uniformly       |                                       |
|                   | distributed over it.         |                                       |
+-------------------+------------------------------+---------------------------------------+
| Stage             | The water level above some   | `USGS Water Science Glossary`_        |
|                   | arbitrary point in the river |                                       |
|                   | and is commonly measured in  |                                       |
|                   | feet.                        |                                       |
+-------------------+------------------------------+---------------------------------------+
| Exceedance        | The probability a given flow | `Searcy (1959)`_                      |
| Probability       | value will be equaled or     |                                       |
|                   | exceeded during a given time |                                       |
|                   | period.                      |                                       |
+-------------------+------------------------------+---------------------------------------+
| Recurrence        | The average number of years  | `USGS Water Science School`_          |
| Interval          | between floods of a certain  |                                       |
|                   | size is the recurrence       |                                       |
|                   | interval or return period.   |                                       |
|                   | The actual number of years   |                                       |
|                   | between floods of any given  |                                       |
|                   | size varies a lot because of |                                       |
|                   | the naturally changing       |                                       |
|                   | climate.                     |                                       |
+-------------------+------------------------------+---------------------------------------+


.. _Hammond et al. (2022): https://doi.org/10.1029/2022WR031930

.. _hyswap: https://doi-usgs.github.io/hyswap/index.html

.. _USDA National Engineering Handbook: https://directives.sc.egov.usda.gov/OpenNonWebContent.aspx?content=17755.wba

.. _USGS Water Science Glossary: https://www.usgs.gov/special-topics/water-science-school/science/water-science-glossary

.. _USGS NWIS: https://waterdata.usgs.gov/nwis

.. _Searcy (1959): https://doi.org/10.3133/wsp1542A

.. _Koehler (2004): https://citeseerx.ist.psu.edu/document?repid=rep1&type=pdf&doi=461ba539a786645e7576720b0a72c0baa1fc4716

.. _USGS Water Science School: https://www.usgs.gov/special-topics/water-science-school/science/100-year-flood
